@@ -46,9 +46,10 @@ function setup_network()
 function create_config()
 {
 	local ip=${1}
+	local netmask=${2}
 
 	put_param ${IFCFG} "IPADDR" ${ip}
-	put_param ${IFCFG} "NETMASK" "255.255.255.255"
+	put_param ${IFCFG} "NETMASK" ${netmask}
 }
 
 function add_ip()
@@ -57,14 +58,16 @@ function add_ip()
 	if [ "x${VE_STATE}" = "xstarting" ]; then
 		setup_network
 	fi
-	for ip in ${IP_ADDR}; do
+	local ipm
+	for ipm in ${IP_ADDR}; do
+		ip_conv $ipm
 		if [ "${IPDELALL}" != "yes" ]; then
-			if grep -qw "${ip}" ${IFCFG} 2>/dev/null; then
+			if grep -qw "${_IP}" ${IFCFG} 2>/dev/null; then
 				break
 			fi
 		fi
 		${IFCFG_DIR}/rc.inet1 stop >/dev/null 2>&1
-		create_config ${ip}
+		create_config ${_IP} ${_NETMASK}
 		${IFCFG_DIR}/rc.inet1 start >/dev/null 2>&1
 		break
 	done
