@@ -20,28 +20,36 @@
 
 #include <sys/syscall.h>
 
+#ifdef VZ_KERNEL_SUPPORTED
+
 #ifdef __ia64__
 #define __NR_fairsched_vcpus	1499
 #define __NR_fairsched_chwt	1502
 #define __NR_fairsched_rate	1504
 #define __NR_setluid		1506
 #define __NR_setublimit		1507
+#ifndef __NR_ioprio_set
 #define __NR_ioprio_set		1274
-#elif __x86_64__
+#endif
+#elif defined(__x86_64__) || defined(__tile__)
 #define __NR_fairsched_cpumask	498
 #define __NR_fairsched_vcpus	499
 #define __NR_setluid		501
 #define __NR_setublimit		502
 #define __NR_fairsched_chwt	506
 #define __NR_fairsched_rate	508
+#ifndef __NR_ioprio_set
 #define __NR_ioprio_set		251
+#endif
 #elif __powerpc__
 #define __NR_fairsched_chwt	402
 #define __NR_fairsched_rate	404
 #define __NR_fairsched_vcpus	405
 #define __NR_setluid		411
 #define __NR_setublimit		412
+#ifndef __NR_ioprio_set
 #define __NR_ioprio_set		273
+#endif
 #elif defined(__i386__) || defined(__sparc__)
 #define __NR_fairsched_chwt	502
 #define __NR_fairsched_rate	504
@@ -49,13 +57,16 @@
 #define __NR_fairsched_cpumask	506
 #define __NR_setluid		511
 #define __NR_setublimit		512
+#ifndef __NR_ioprio_set
 #ifdef __sparc__
 #define __NR_ioprio_set		196
 #else
 #define __NR_ioprio_set		289
 #endif
+#endif
 #else
-#error "no syscall for this arch"
+#error "VZ kernel not supported in this architecture"
 #endif
 
 #endif
+#endif /* VZ_KERNEL_SUPPORTED */
