@@ -144,6 +144,7 @@ static vps_config config[] = {
 {"FEATURES",	NULL, PARAM_FEATURES},
 {"IOPRIO",	NULL, PARAM_IOPRIO},
 {"BOOTORDER",	NULL, PARAM_BOOTORDER},
+{"STOP_TIMEOUT", NULL, PARAM_STOP_TIMEOUT},
 
 /* These ones are either known parameters for global config file,
  * or some obsoleted parameters used in the past. In both cases
@@ -358,6 +359,14 @@ static int conf_store_ulong(list_head_t *conf, char *name, unsigned long *val)
 	return conf_store_str(conf, name, buf);
 }
 
+static int conf_store_int(list_head_t *conf, char *name, int val)
+{
+	char buf[] = "2147483647"; /* INT_MAX */
+
+	snprintf(buf, sizeof(buf), "%d", val);
+	return conf_store_str(conf, name, buf);
+}
+
 static int conf_store_bitmap(list_head_t *conf, char *name,
 			     unsigned long *val, int nmaskbits)
 {
@@ -432,18 +441,12 @@ static int parse_ioprio(int id, io_param *io, char *val)
 static int store_ioprio(vps_param *old_p, vps_param *vps_p,
 				 vps_config *conf, list_head_t *conf_h)
 {
-	io_param *io_param;
-	char buf[20];
-
-	io_param = &vps_p->res.io;
+	io_param *io_param = &vps_p->res.io;
 
 	if (conf->id != PARAM_IOPRIO || io_param->ioprio < 0)
 		return 0;
 
-	snprintf(buf, sizeof(buf), "%s=\"%d\"", conf->name, io_param->ioprio);
-	add_str_param(conf_h, buf);
-
-	return 0;
+	return conf_store_int(conf_h, conf->name, io_param->ioprio);
 }
 
 /******************** Iptables *************************/
@@ -530,7 +533,8 @@ static long long get_mul(char c)
 
 /* This function parses string in form xxx[GMKPB]
  */
-static const char *parse_ul_sfx(const char *str, unsigned long long *val, int divisor)
+static const char *parse_ul_sfx(const char *str, unsigned long long *val,
+		int divisor, int allow_unlimited)
 {
 	long long n;
 	char *tail;
@@ -538,7 +542,7 @@ static const char *parse_ul_sfx(const char *str, unsigned long long *val, int di
 
 	if (!str || !val)
 		return NULL;
-	if (!strncmp(str, "unlimited", 9)) {
+	if (allow_unlimited && !strncmp(str, "unlimited", 9)) {
 		*val = LONG_MAX;
 		return str + 9;
 	}
@@ -572,12 +576,13 @@ static const char *parse_ul_sfx(const char *str, unsigned long long *val, int di
 /* This function parses string in form xxx[GMKPB]:yyy[GMKPB]
  * If :yyy is omitted, it is set to xxx.
  */
-static int parse_twoul_sfx(const char *str, unsigned long *val, int divisor)
+static int parse_twoul_sfx(const char *str, unsigned long *val,
+		int divisor, int allow_unlimited)
 {
 	unsigned long long tmp;
 	int ret = 0;
 
-	if (!(str = parse_ul_sfx(str, &tmp, divisor)))
+	if (!(str = parse_ul_sfx(str, &tmp, divisor, allow_unlimited)))
 		return ERR_INVAL;
 	if (tmp > LONG_MAX) {
 		tmp = LONG_MAX;
@@ -585,7 +590,7 @@ static int parse_twoul_sfx(const char *str, unsigned long *val, int divisor)
 	}
 	val[0] = tmp;
 	if (*str == ':') {
-		str = parse_ul_sfx(++str, &tmp, divisor);
+		str = parse_ul_sfx(++str, &tmp, divisor, allow_unlimited);
 		if (!str || *str != '\0')
 			return ERR_INVAL;
 		if (tmp > LONG_MAX) {
@@ -657,7 +662,7 @@ static int parse_ub(vps_param *vps_p, const char *val, int id, int divisor)
 
 	if (conf_get_by_id(config, id) == NULL)
 		return ERR_OTHER;
-	ret = parse_twoul_sfx(val, res.limit, divisor);
+	ret = parse_twoul_sfx(val, res.limit, divisor, 1);
 	if (ret && ret != ERR_LONG_TRUNC)
 		return ret;
 	res.res_id = id;
@@ -695,7 +700,7 @@ static int parse_vswap(ub_param *ub, const char *val, int id, int force)
 	if (conf_get_by_id(config, id) == NULL)
 		return ERR_OTHER;
 
-	tail = parse_ul_sfx(val, &tmp, 1);
+	tail = parse_ul_sfx(val, &tmp, 1, 1);
 	if (tail == NULL)
 		return ERR_INVAL;
 	if (*tail != '\0')
@@ -972,7 +977,7 @@ static int parse_dq(unsigned long **param, const char *val, int sfx)
 	tmp = malloc(sizeof(unsigned long) * 2);
 	if (tmp == NULL)
 		return ERR_NOMEM;
-	ret = parse_twoul_sfx(val, tmp, sfx ? 1024 : 0);
+	ret = parse_twoul_sfx(val, tmp, sfx ? 1024 : 0, 0);
 	if (ret && ret != ERR_LONG_TRUNC) {
 		free(tmp);
 		return ret;
@@ -1370,6 +1375,11 @@ static int store_misc(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 	case PARAM_LOCAL_GID:
 		ret = conf_store_ulong(conf_h, conf->name, misc->local_gid);
 		break;
+	case PARAM_STOP_TIMEOUT:
+		if (misc->stop_timeout >= 0)
+			ret = conf_store_int(conf_h, conf->name,
+					misc->stop_timeout);
+		break;
 	}
 	return ret;
 }
@@ -2219,6 +2229,14 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 	case PARAM_MOUNT_OPTS:
 		ret = conf_parse_str(&vps_p->res.fs.mount_opts, val);
 		break;
+	case PARAM_STOP_TIMEOUT:
+		if (vps_p->res.misc.stop_timeout != -1)
+			return ERR_DUP;
+		if (parse_int(val, &int_id))
+			return ERR_INVAL;
+		if (int_id < 0)
+			return ERR_INVAL;
+		vps_p->res.misc.stop_timeout = int_id;
 	case PARAM_IGNORED:
 		/* Well known but ignored parameter */
 		break;
@@ -2575,6 +2593,7 @@ vps_param *init_vps_param()
 	param->res.meminfo.mode = -1;
 	param->res.io.ioprio = -1;
 	param->opt.mode = -1;
+	param->res.misc.stop_timeout = -1;
 
 	return param;
 }
@@ -2881,6 +2900,7 @@ static void merge_misc(misc_param *dst, misc_param *src)
 	MERGE_P(local_gid)
 	MERGE_P(bootorder)
 	MERGE_INT(wait)
+	MERGE_INT2(stop_timeout)
 }
 
 static void merge_dq(dq_param *dst, dq_param *src)
