@@ -124,9 +124,15 @@ int env_wait(int pid)
 {
 	int ret, status;
 
-	while ((ret = waitpid(pid, &status, 0)) == -1)
-		if (errno != EINTR)
+	do {
+		ret = waitpid(pid, &status, 0);
+		if (ret == -1) {
+			if (errno == EINTR)
+				continue;
 			break;
+		}
+	} while (WIFSTOPPED(status) || WIFCONTINUED(status));
+
 	if (ret == pid) {
 		ret = VZ_SYSTEM_ERROR;
 		if (WIFEXITED(status))
@@ -449,7 +455,7 @@ int vps_run_script(vps_handler *h, envid_t veid, char *script, vps_param *vps_p)
 		is_mounted = vps_is_mounted(root, private);
 		if (is_mounted == 0) {
 			if ((ret = fsmount(veid, &vps_p->res.fs,
-				&vps_p->res.dq )))
+				&vps_p->res.dq, SKIP_FSCK)))
 			{
 				return ret;
 			}
