@@ -94,7 +94,12 @@ static int load_ploop_lib(void)
 		void *padding[32];
 	} src = { {0}, {0} };
 
-	h = dlopen("libploop.so", RTLD_LAZY);
+	h = dlopen("libploop.so.1", RTLD_LAZY);
+	if (!h && (errno == ENOENT || errno == ESRCH))
+		/* ploop-lib < 1.9 had no .so version
+		 * FIXME: remove this later
+		 */
+		h = dlopen("libploop.so", RTLD_LAZY);
 	if (!h) {
 		logger(-1, 0, "Can't load ploop library: %s", dlerror());
 		logger(-1, 0, "Please install ploop packages!");
@@ -616,7 +621,10 @@ int vzctl_env_convert_ploop(vps_handler *h, envid_t veid,
 		goto err;
 	}
 	/* Fix its mode just in case */
-	chmod(fs->private, 0700);
+	if (chmod(fs->private, 0700))
+		/* Too late to rollback, so just issue a warning */
+		logger(-1, errno, "Warning: chmod(%s, 0700) failed",
+				fs->private);
 	/* Finally, del the old private */
 	destroydir(tmp_private);
 	logger(0, 0, "Container was successfully converted "
