@@ -66,7 +66,7 @@ static void usage(int rc)
 "   [--layout ploop|simfs] [--hostname <name>] [--name <name>] [--ipadd <addr>]\n"
 "   [--diskspace <kbytes>] [--private <path>] [--root <path>]\n"
 "   [--local_uid <UID>] [--local_gid <GID>]\n"
-"vzctl start <ctid> [--force] [--wait]\n"
+"vzctl start <ctid> [--force] [--wait] [--skip-fsck]\n"
 "vzctl destroy | mount | umount | stop | restart | status <ctid>\n"
 #ifdef HAVE_PLOOP
 "vzctl convert <ctid> [--layout ploop[:mode]] [--diskspace <kbytes>]\n"
@@ -102,6 +102,7 @@ static void usage(int rc)
 "   [--features <name:on|off>] [--name <vename>] [--ioprio <N>]\n"
 "   [--pci_add [<domain>:]<bus>:<slot>.<func>] [--pci_del <d:b:s.f>]\n"
 "   [--iptables <name>] [--disabled <yes|no>]\n"
+"   [--stop-timeout <seconds>\n"
 "   [UBC parameters]\n"
 "\n"
 "UBC parameters (N - items, P - pages, B - bytes):\n"
